## Version 1.0.0

- Changed: Modenized build method, added linting
- Added: Type annotations
- Added: Frequency response calculation
- Added: Github actions based PyPI release workflow
- Fixed: Wrong step in ZOH discretization
